@@ -94,9 +94,10 @@ class startControl(QThread):
         data = 0
         gqrx_freq = self.getfreq(self.gqrxIPv, GQRX_PORT, 'gqrx')
         if gqrx_freq.decode("utf-8").find('\n') != -1:
-            print('1111', gqrx_freq.decode("utf-8"))
-            gqrx_freq = gqrx_freq[0:gqrx_freq.find('\n')]
-            print('2222', gqrx_freq)
+            #print('1111', gqrx_freq.decode("utf-8"))
+            #gqrx_freq = gqrx_freq[0:gqrx_freq.find('\n')]
+            gqrx_freq = gqrx_freq.decode("utf-8")[0:gqrx_freq.decode("utf-8").find('\n')]
+            #print('2222', gqrx_freq)
         else:
             print('ERROR')
         old_gqrx_freq = 0 #gqrx_freq
@@ -107,14 +108,14 @@ class startControl(QThread):
                 #rig_freq = str(self.getfreq(TCP_IP, RIG_PORT, endpoint))
                 rig_freq = self.getfreq(TCP_IP, RIG_PORT, endpoint)
                 if endpoint == 'hamlib':
-                    print('rig freq', rig_freq)
-                    if rig_freq.find('\n') != -1:
-                        rig_freq = rig_freq[0:rig_freq.find('\n')]
-                        print('rig freq', rig_freq)
+                    #print('rig freq', rig_freq)
+                    if rig_freq.decode("utf-8").find('\n') != -1:
+                        rig_freq = rig_freq.decode("utf-8")[0:rig_freq.decode("utf-8").find('\n')]
+                        #print('rig freq', rig_freq)
                 else:
-                    if rig_freq.find('.') != -1:
-                        rig_freq = rig_freq[0:rig_freq.find('.')]
-                print('rig freq', rig_freq)
+                    if rig_freq.decode("utf-8").find('.') != -1:
+                        rig_freq = rig_freq.decode("utf-8")[0:rig_freq.decode("utf-8").find('.')]
+                #print('rig freq', rig_freq)
                 if rig_freq != old_rig_freq:
                     # set gqrx to Hamlib/flrig frequency
                     self.setfreq(self.gqrxIPv, GQRX_PORT, 'gqrx', float(rig_freq))
@@ -132,9 +133,9 @@ class startControl(QThread):
             
        
             if self.control == 1 or self.control == 2:
-                gqrx_freq = str(self.getfreq(self.gqrxIPv, GQRX_PORT, 'gqrx'))
-                if gqrx_freq.find('\n') != -1:
-                    gqrx_freq = gqrx_freq[0:gqrx_freq.find('\n')]
+                gqrx_freq = self.getfreq(self.gqrxIPv, GQRX_PORT, 'gqrx')
+                if gqrx_freq.decode("utf-8").find('\n') != -1:
+                    gqrx_freq = gqrx_freq.decode("utf-8")[0:gqrx_freq.decode("utf-8").find('\n')]
                 if self.control == 2 and self.ifModev == 'Y':
                     if gqrx_freq != old_gqrx_freq:
                         if gqrx_freq > self.ifFreqv:
@@ -210,7 +211,7 @@ class startControl(QThread):
             server_address = (IP, PORT)
             sock.connect(server_address)
             build_msg = 'F ' + str(freq) + '\n'
-            MESSAGE = bytes(build_msg)
+            MESSAGE = bytes(build_msg, 'utf-8')
             sock.sendall(MESSAGE)
             #print ('set', endpoint, ' ',IP ,' ',build_msg,MESSAGE)
             data = sock.recv(16)
@@ -250,7 +251,7 @@ class startControl(QThread):
             server_address = (IP, PORT)
             sock.connect(server_address)
             build_msg = 'M ' + str(mode) + ' 0' + '\n'
-            MESSAGE = bytes(build_msg)
+            MESSAGE = bytes(build_msg, 'utf-8')
             sock.sendall(MESSAGE)
             data = ''
             data = sock.recv(7)
